@@ -26,7 +26,7 @@ var stringsOperatorScenarios = []expressionScenario{
 		description: "Interpolation - just escape",
 		expression:  `"\\"`,
 		expected: []string{
-			"D0, P[], (!!str)::\\\\\n",
+			"D0, P[], (!!str)::\\\n",
 		},
 	},
 	{
@@ -47,6 +47,15 @@ var stringsOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!str)::Hi (.value)\n",
 		},
 	},
+	{
+		skipDoc:     true,
+		description: "Interpolation - don't!",
+		document:    `value: things`,
+		expression:  `"Hi \\(.value)"`,
+		expected: []string{
+			"D0, P[], (!!str)::Hi \\(.value)\n",
+		},
+	},
 	{
 		skipDoc:     true,
 		description: "Interpolation - random close bracket",
@@ -63,6 +72,13 @@ var stringsOperatorScenarios = []expressionScenario{
 		expression:    `"Hi \("`,
 		expectedError: "unclosed interpolation string \\(",
 	},
+	{
+		skipDoc:       true,
+		description:   "Interpolation - unclosed interpolation string due to escape",
+		document:      `value: things`,
+		expression:    `"Hi \(\)"`,
+		expectedError: "unclosed interpolation string \\(",
+	},
 	{
 		description:    "To up (upper) case",
 		subdescription: "Works with unicode characters",
